pub struct AddrParseError(/* private fields */);Expand description
An error which can be returned when parsing an IP address or a socket address.
This error is used as the error type for the FromStr implementation for
IpAddr, Ipv4Addr, Ipv6Addr, SocketAddr, SocketAddrV4, and
SocketAddrV6.